@@ -25,7 +25,7 @@
  * following:                                                              *
  * o Integrates source code from Nmap                                      *
  * o Reads or includes Nmap copyrighted data files, such as                *
- *   nmap-os-fingerprints or nmap-service-probes.                          *
+ *   nmap-os-db or nmap-service-probes.                                    *
  * o Executes Nmap and parses the results (as opposed to typical shell or  *
  *   execution-menu apps, which simply display raw Nmap output and so are  *
  *   not derivative works.)                                                * 
@@ -60,7 +60,7 @@
  * As a special exception to the GPL terms, Insecure.Com LLC grants        *
  * permission to link the code of this program with any version of the     *
  * OpenSSL library which is distributed under a license identical to that  *
- * listed in the included Copying.OpenSSL file, and distribute linked      *
+ * listed in the included COPYING.OpenSSL file, and distribute linked      *
  * combinations including the two. You must obey the GNU GPL in all        *
  * respects for all of the code used other than OpenSSL.  If you modify    *
  * this file, you may extend this exception to your version of the file,   *
@@ -92,13 +92,13 @@
  * This program is distributed in the hope that it will be useful, but     *
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
- * General Public License for more details at                              *
- * http://www.gnu.org/copyleft/gpl.html , or in the COPYING file included  *
- * with Nmap.                                                              *
+ * General Public License v2.0 for more details at                         *
+ * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
+ * included with Nmap.                                                     *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: Target.h 7145 2008-04-11 03:54:44Z david $ */
+/* $Id: Target.h 8759 2008-07-11 06:12:38Z david $ */
 
 #ifndef TARGET_H
 #define TARGET_H
@@ -113,6 +113,7 @@
 #include "portreasons.h"
 #include "portlist.h"
 #include "tcpip.h"
+#include "scan_engine.h"
 
 #ifndef INET6_ADDRSTRLEN
 #define INET6_ADDRSTRLEN 46
@@ -126,6 +127,7 @@ struct host_timeout_nfo {
   unsigned long msecs_used; /* How many msecs has this Target used? */
   bool toclock_running; /* Is the clock running right now? */
   struct timeval toclock_start; /* When did the clock start? */
+  time_t host_start, host_end; /* The absolute start and end for this host */
 };
 
 class Target {
@@ -222,6 +224,9 @@ class Target {
      current time handy.  You might as well also pass NULL if the
      clock is not running, as the func won't need the time. */
   bool timedOut(const struct timeval *now);
+  /* Return time_t for the start and end time of this host */
+  time_t StartTime() { return htn.host_start; }
+  time_t EndTime() { return htn.host_end; }
 
   /* Takes a 6-byte MAC address */
   int setMACAddress(const u8 *addy);
@@ -263,6 +268,13 @@ class Target {
 
   state_reason_t reason;
 
+  /* A probe that is known to receive a response. This is used to hold the
+     current timing ping probe type during scanning. */
+  probespec pingprobe;
+  /* The state the port or protocol entered when the response to pingprobe was
+     received. */
+  int pingprobe_state;
+
   private:
   void Initialize();
   void FreeInternal(); // Free memory allocated inside this object
