@@ -27,8 +27,8 @@ APP_WEB_SITE = "http://nmap.org/zenmap"
 APP_DOWNLOAD_SITE = "http://nmap.org/download.html"
 APP_COPYRIGHT = "Copyright 2005-2008 Insecure.Com LLC"
 
-NMAP_DISPLAY_NAME = "Nmap"
+NMAP_DISPLAY_NAME = u"Nmap"
 NMAP_WEB_SITE = "http://nmap.org"
 
 UMIT_DISPLAY_NAME = "Umit"
-UMIT_WEB_SITE = "http://umit.sourceforge.net/"
+UMIT_WEB_SITE = "http://www.umitproject.org/"
